import { BrowserOptions } from '@sentry/browser';
import { Integration } from '@sentry/core';
import { RendererProcessAnrOptions } from '../common/ipc';
/** Get the default integrations for the renderer SDK. */
export declare function getDefaultIntegrations(options: ElectronRendererOptions): Integration[];
interface ElectronRendererOptions extends Omit<BrowserOptions, 'dsn' | 'environment' | 'release'> {
    /**
     * Enables ANR detection in this renderer process.
     *
     * Optionally accepts an object of options to configure ANR detection.
     *
     * {
     *   pollInterval: number; // Defaults to 1000ms
     *   anrThreshold: number; // Defaults to 5000ms
     *   captureStackTrace: boolean; // Defaults to false
     * }
     *
     * Defaults to 'false'.
     */
    anrDetection?: Partial<RendererProcessAnrOptions> | boolean;
    /** @deprecated `dsn` should only be passed to the main process `Sentry.init` call */
    dsn?: string;
    /** @deprecated `release` should only be passed to the main process `Sentry.init` call */
    release?: string;
    /** @deprecated `environment` should only be passed to the main process `Sentry.init` call */
    environment?: string;
}
/**
 * Initialize Sentry in the Electron renderer process
 * @param options SDK options
 * @param originalInit Optional init function for a specific framework SDK
 * @returns
 */
export declare function init<O extends ElectronRendererOptions>(options?: ElectronRendererOptions & O, originalInit?: (if_you_get_a_typescript_error_ensure_sdks_use_version_v9_25_0: O) => void): void;
export {};
//# sourceMappingURL=sdk.d.ts.map